package Source::Package;

use strict;
use warnings;
use Source::Shared::Utils::Downloader qw/cached_download/;

our $VERSION=0.178;
our $verbose=0;

use Source::Package::Comparators;
sub get_raw_epoch_comparator {
    return \&Source::Package::Comparators::null_epoch_comparator;
}
sub get_raw_version_comparator {
    return \&Source::Package::Comparators::pure_rpm_version_comparator;
}
sub get_raw_release_comparator {
    return \&Source::Package::Comparators::pure_rpm_release_comparator;
}

sub new {
    my $proto=shift;
    my $class=ref($proto) || $proto;
    my $self = {
	#-cachedir=>'in',
	-epoch => undef,
	-version => 0,
	-release => 0,
	@_,
    };
    bless($self,$class);
}

sub version {return $_[0]->{-version}}
sub release {return $_[0]->{-release}}
sub epoch {return $_[0]->{-epoch}}
sub name {return $_[0]->{-name}}
sub url {return $_[0]->{-url}}
sub file {
    my ($self)=@_;
    my $file=$self->{-file};
    return $file if defined $file;
    return $self->_download if $self->{-url};
    #removed from repo API
    #return $self->{-repo}->download($self) if $self->{-repo};
    return;
}

sub debugstring {
    my ($self)=@_;
    my $out='';
    foreach my $key (sort {$a cmp $b} keys(%$self)) {
	my $val=$self->{$key};
	$out.='['.$key.'->'.(defined($val)?$val : 'undef').']';
    }
    return $out;
}

sub is_pkg {
    die "is_pkg: not implemented!";
}

sub file2pkg {
    die "file2pkg: not implemented!";
}

### TODO check url?
sub _download {
    my ($self)=@_;
    my $file=$self->{-file};
    return $file if defined $file and -e $file and -s $file;
    my $url=$self->url;
    $file=cached_download($url,$self->{-cachedir});
    $self->{-file}=$file;
    return $file;
}

1;
