package Source::Package::Tarball;

use strict;
use warnings;

use File::Basename;
use Source::Package;
our @ISA=qw/Source::Package/;

our $VERSION=0.001;
our $verbose=1;

# used in BundleImport
sub trim_package_version {
    my $class=shift;
    return &__tarball_trim_version;
}

# used in BundleImport
sub guess_package_name_version {
    my $class=shift;
    return &__tarball_guess_pkg_name_version;
}

sub is_pkg {
   my ($self,$item)=@_;
   return if not (defined $item and -e $item and not -d $item);
   my ($name)=$self->guess_package_name_version($item);
   return defined $name;
}

sub file2pkg {
    my ($self,$file)=@_;
    return unless $file and -e $file;
    die "Oops: file2pkg: strange file $file" unless $self->is_pkg($file);
    my ($name,$version)=$self->guess_package_name_version($file);
    return $self->new(
	-name => $name,
	-version => $version,
	-file => $file,
	);
}

sub __tarball_guess_pkg_name_version {
    my ($file)=@_;
    my $bundle_version=0;
    my $bundle_name;
    # git dir support
    if (-d $file) {
	$bundle_name=basename($file);
	if ($bundle_name=~/^(.+)-v?([\d\.]+(?:-[A-Za-z]\w*|[abpn]\d+)?)/) {
	    $bundle_version=$2;
	    $bundle_name=basename($1);
	} elsif ($bundle_name=~s/\.git$//) {
	    $bundle_version=0;
	} else {
	    return;
	}
    } else {
	return unless $file=~/^(.+)-v?([\d\.]+(?:-[A-Za-z]\w*|[abpn]\d+)?)\.(tar\..+|t[gbx]z2?|7z|tar|jar|zip|rar)$/;
	$bundle_version=$2;
	$bundle_name=basename($1);
    }
    print STDERR "tarball_guess_pkg_name_version: bundle_name=$bundle_name bundle_version=$bundle_version\n" if $verbose;
    return ($bundle_name,$bundle_version);
}

sub __tarball_trim_version {
    my ($ver,$module)=@_;

    #print STDERR "2:ver=$ver\n";
    $ver=~s/(-\d+)\D+$/$1/;
    #print STDERR "3:ver=$ver\n";
    $ver=~s/-/_/g;

    return $ver;
}


1;
